==> aws-cdk-scala-nimblestudio_3-0.4.0-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"nimblestudio","t":"nimblestudio","d":"","k":"static"},
{"l":"io/burkard/cdk/services/nimblestudio.html","n":"io.burkard.cdk.services.nimblestudio","t":"package io.burkard.cdk.services.nimblestudio","d":"io/burkard/cdk/services/nimblestudio","k":"package"},
{"l":"io/burkard/cdk/services/nimblestudio/ActiveDirectoryComputerAttributeProperty$.html","n":"ActiveDirectoryComputerAttributeProperty","t":"object ActiveDirectoryComputerAttributeProperty","d":"io/burkard/cdk/services/nimblestudio/ActiveDirectoryComputerAttributeProperty$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/ActiveDirectoryComputerAttributeProperty$.html","n":"apply","t":"def apply(name: Option[String], value: Option[String]): ActiveDirectoryComputerAttributeProperty","d":"io/burkard/cdk/services/nimblestudio/ActiveDirectoryComputerAttributeProperty$","k":"def"},
{"l":"io/burkard/cdk/services/nimblestudio/ActiveDirectoryConfigurationProperty$.html","n":"ActiveDirectoryConfigurationProperty","t":"object ActiveDirectoryConfigurationProperty","d":"io/burkard/cdk/services/nimblestudio/ActiveDirectoryConfigurationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/ActiveDirectoryConfigurationProperty$.html","n":"apply","t":"def apply(organizationalUnitDistinguishedName: Option[String], directoryId: Option[String], computerAttributes: Option[List[_]]): ActiveDirectoryConfigurationProperty","d":"io/burkard/cdk/services/nimblestudio/ActiveDirectoryConfigurationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/nimblestudio/CfnLaunchProfile$.html","n":"CfnLaunchProfile","t":"object CfnLaunchProfile","d":"io/burkard/cdk/services/nimblestudio/CfnLaunchProfile$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/CfnLaunchProfile$.html","n":"apply","t":"def apply(internalResourceId: String, streamConfiguration: StreamConfigurationProperty, ec2SubnetIds: List[String], name: String, studioComponentIds: List[String], launchProfileProtocolVersions: List[String], studioId: String, description: Option[String], tags: Option[Map[String, String]])(implicit stackCtx: Stack): CfnLaunchProfile","d":"io/burkard/cdk/services/nimblestudio/CfnLaunchProfile$","k":"def"},
{"l":"io/burkard/cdk/services/nimblestudio/CfnLaunchProfileProps$.html","n":"CfnLaunchProfileProps","t":"object CfnLaunchProfileProps","d":"io/burkard/cdk/services/nimblestudio/CfnLaunchProfileProps$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/CfnLaunchProfileProps$.html","n":"apply","t":"def apply(streamConfiguration: StreamConfigurationProperty, ec2SubnetIds: List[String], name: String, studioComponentIds: List[String], launchProfileProtocolVersions: List[String], studioId: String, description: Option[String], tags: Option[Map[String, String]]): CfnLaunchProfileProps","d":"io/burkard/cdk/services/nimblestudio/CfnLaunchProfileProps$","k":"def"},
{"l":"io/burkard/cdk/services/nimblestudio/CfnStreamingImage$.html","n":"CfnStreamingImage","t":"object CfnStreamingImage","d":"io/burkard/cdk/services/nimblestudio/CfnStreamingImage$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/CfnStreamingImage$.html","n":"apply","t":"def apply(internalResourceId: String, name: String, ec2ImageId: String, studioId: String, description: Option[String], tags: Option[Map[String, String]])(implicit stackCtx: Stack): CfnStreamingImage","d":"io/burkard/cdk/services/nimblestudio/CfnStreamingImage$","k":"def"},
{"l":"io/burkard/cdk/services/nimblestudio/CfnStreamingImageProps$.html","n":"CfnStreamingImageProps","t":"object CfnStreamingImageProps","d":"io/burkard/cdk/services/nimblestudio/CfnStreamingImageProps$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/CfnStreamingImageProps$.html","n":"apply","t":"def apply(name: String, ec2ImageId: String, studioId: String, description: Option[String], tags: Option[Map[String, String]]): CfnStreamingImageProps","d":"io/burkard/cdk/services/nimblestudio/CfnStreamingImageProps$","k":"def"},
{"l":"io/burkard/cdk/services/nimblestudio/CfnStudio$.html","n":"CfnStudio","t":"object CfnStudio","d":"io/burkard/cdk/services/nimblestudio/CfnStudio$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/CfnStudio$.html","n":"apply","t":"def apply(internalResourceId: String, displayName: String, studioName: String, adminRoleArn: String, userRoleArn: String, studioEncryptionConfiguration: Option[StudioEncryptionConfigurationProperty], tags: Option[Map[String, String]])(implicit stackCtx: Stack): CfnStudio","d":"io/burkard/cdk/services/nimblestudio/CfnStudio$","k":"def"},
{"l":"io/burkard/cdk/services/nimblestudio/CfnStudioComponent$.html","n":"CfnStudioComponent","t":"object CfnStudioComponent","d":"io/burkard/cdk/services/nimblestudio/CfnStudioComponent$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/CfnStudioComponent$.html","n":"apply","t":"def apply(internalResourceId: String, name: String, studioId: String, `type`: String, subtype: Option[String], initializationScripts: Option[List[_]], description: Option[String], tags: Option[Map[String, String]], ec2SecurityGroupIds: Option[List[String]], configuration: Option[StudioComponentConfigurationProperty], scriptParameters: Option[List[_]])(implicit stackCtx: Stack): CfnStudioComponent","d":"io/burkard/cdk/services/nimblestudio/CfnStudioComponent$","k":"def"},
{"l":"io/burkard/cdk/services/nimblestudio/CfnStudioComponentProps$.html","n":"CfnStudioComponentProps","t":"object CfnStudioComponentProps","d":"io/burkard/cdk/services/nimblestudio/CfnStudioComponentProps$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/CfnStudioComponentProps$.html","n":"apply","t":"def apply(name: String, studioId: String, `type`: String, subtype: Option[String], initializationScripts: Option[List[_]], description: Option[String], tags: Option[Map[String, String]], ec2SecurityGroupIds: Option[List[String]], configuration: Option[StudioComponentConfigurationProperty], scriptParameters: Option[List[_]]): CfnStudioComponentProps","d":"io/burkard/cdk/services/nimblestudio/CfnStudioComponentProps$","k":"def"},
{"l":"io/burkard/cdk/services/nimblestudio/CfnStudioProps$.html","n":"CfnStudioProps","t":"object CfnStudioProps","d":"io/burkard/cdk/services/nimblestudio/CfnStudioProps$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/CfnStudioProps$.html","n":"apply","t":"def apply(displayName: String, studioName: String, adminRoleArn: String, userRoleArn: String, studioEncryptionConfiguration: Option[StudioEncryptionConfigurationProperty], tags: Option[Map[String, String]]): CfnStudioProps","d":"io/burkard/cdk/services/nimblestudio/CfnStudioProps$","k":"def"},
{"l":"io/burkard/cdk/services/nimblestudio/ComputeFarmConfigurationProperty$.html","n":"ComputeFarmConfigurationProperty","t":"object ComputeFarmConfigurationProperty","d":"io/burkard/cdk/services/nimblestudio/ComputeFarmConfigurationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/ComputeFarmConfigurationProperty$.html","n":"apply","t":"def apply(endpoint: Option[String], activeDirectoryUser: Option[String]): ComputeFarmConfigurationProperty","d":"io/burkard/cdk/services/nimblestudio/ComputeFarmConfigurationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/nimblestudio/LicenseServiceConfigurationProperty$.html","n":"LicenseServiceConfigurationProperty","t":"object LicenseServiceConfigurationProperty","d":"io/burkard/cdk/services/nimblestudio/LicenseServiceConfigurationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/LicenseServiceConfigurationProperty$.html","n":"apply","t":"def apply(endpoint: Option[String]): LicenseServiceConfigurationProperty","d":"io/burkard/cdk/services/nimblestudio/LicenseServiceConfigurationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/nimblestudio/ScriptParameterKeyValueProperty$.html","n":"ScriptParameterKeyValueProperty","t":"object ScriptParameterKeyValueProperty","d":"io/burkard/cdk/services/nimblestudio/ScriptParameterKeyValueProperty$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/ScriptParameterKeyValueProperty$.html","n":"apply","t":"def apply(value: Option[String], key: Option[String]): ScriptParameterKeyValueProperty","d":"io/burkard/cdk/services/nimblestudio/ScriptParameterKeyValueProperty$","k":"def"},
{"l":"io/burkard/cdk/services/nimblestudio/SharedFileSystemConfigurationProperty$.html","n":"SharedFileSystemConfigurationProperty","t":"object SharedFileSystemConfigurationProperty","d":"io/burkard/cdk/services/nimblestudio/SharedFileSystemConfigurationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/SharedFileSystemConfigurationProperty$.html","n":"apply","t":"def apply(windowsMountDrive: Option[String], endpoint: Option[String], linuxMountPoint: Option[String], shareName: Option[String], fileSystemId: Option[String]): SharedFileSystemConfigurationProperty","d":"io/burkard/cdk/services/nimblestudio/SharedFileSystemConfigurationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/nimblestudio/StreamConfigurationProperty$.html","n":"StreamConfigurationProperty","t":"object StreamConfigurationProperty","d":"io/burkard/cdk/services/nimblestudio/StreamConfigurationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/StreamConfigurationProperty$.html","n":"apply","t":"def apply(clipboardMode: String, ec2InstanceTypes: List[String], streamingImageIds: List[String], maxSessionLengthInMinutes: Option[Number]): StreamConfigurationProperty","d":"io/burkard/cdk/services/nimblestudio/StreamConfigurationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/nimblestudio/StudioComponentConfigurationProperty$.html","n":"StudioComponentConfigurationProperty","t":"object StudioComponentConfigurationProperty","d":"io/burkard/cdk/services/nimblestudio/StudioComponentConfigurationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/StudioComponentConfigurationProperty$.html","n":"apply","t":"def apply(activeDirectoryConfiguration: Option[ActiveDirectoryConfigurationProperty], computeFarmConfiguration: Option[ComputeFarmConfigurationProperty], licenseServiceConfiguration: Option[LicenseServiceConfigurationProperty], sharedFileSystemConfiguration: Option[SharedFileSystemConfigurationProperty]): StudioComponentConfigurationProperty","d":"io/burkard/cdk/services/nimblestudio/StudioComponentConfigurationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/nimblestudio/StudioComponentInitializationScriptProperty$.html","n":"StudioComponentInitializationScriptProperty","t":"object StudioComponentInitializationScriptProperty","d":"io/burkard/cdk/services/nimblestudio/StudioComponentInitializationScriptProperty$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/StudioComponentInitializationScriptProperty$.html","n":"apply","t":"def apply(platform: Option[String], script: Option[String], launchProfileProtocolVersion: Option[String], runContext: Option[String]): StudioComponentInitializationScriptProperty","d":"io/burkard/cdk/services/nimblestudio/StudioComponentInitializationScriptProperty$","k":"def"},
{"l":"io/burkard/cdk/services/nimblestudio/StudioEncryptionConfigurationProperty$.html","n":"StudioEncryptionConfigurationProperty","t":"object StudioEncryptionConfigurationProperty","d":"io/burkard/cdk/services/nimblestudio/StudioEncryptionConfigurationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/StudioEncryptionConfigurationProperty$.html","n":"apply","t":"def apply(keyType: String, keyArn: Option[String]): StudioEncryptionConfigurationProperty","d":"io/burkard/cdk/services/nimblestudio/StudioEncryptionConfigurationProperty$","k":"def"},
{"l":"docs/index.html","n":"nimblestudio","t":"nimblestudio","d":"","k":"static"}];

==> aws-cdk-scala-nimblestudio_3-0.5.0-javadoc.jar: scripts/searchData.js <==
pages = [{"l":"index.html","n":"nimblestudio","t":"nimblestudio","d":"","k":"static"},
{"l":"io/burkard/cdk/services/nimblestudio.html","n":"io.burkard.cdk.services.nimblestudio","t":"package io.burkard.cdk.services.nimblestudio","d":"io/burkard/cdk/services/nimblestudio","k":"package"},
{"l":"io/burkard/cdk/services/nimblestudio/ActiveDirectoryComputerAttributeProperty$.html","n":"ActiveDirectoryComputerAttributeProperty","t":"object ActiveDirectoryComputerAttributeProperty","d":"io/burkard/cdk/services/nimblestudio/ActiveDirectoryComputerAttributeProperty$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/ActiveDirectoryComputerAttributeProperty$.html","n":"apply","t":"def apply(name: Option[String], value: Option[String]): ActiveDirectoryComputerAttributeProperty","d":"io/burkard/cdk/services/nimblestudio/ActiveDirectoryComputerAttributeProperty$","k":"def"},
{"l":"io/burkard/cdk/services/nimblestudio/ActiveDirectoryConfigurationProperty$.html","n":"ActiveDirectoryConfigurationProperty","t":"object ActiveDirectoryConfigurationProperty","d":"io/burkard/cdk/services/nimblestudio/ActiveDirectoryConfigurationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/ActiveDirectoryConfigurationProperty$.html","n":"apply","t":"def apply(directoryId: Option[String], organizationalUnitDistinguishedName: Option[String], computerAttributes: Option[List[_]]): ActiveDirectoryConfigurationProperty","d":"io/burkard/cdk/services/nimblestudio/ActiveDirectoryConfigurationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/nimblestudio/CfnLaunchProfile$.html","n":"CfnLaunchProfile","t":"object CfnLaunchProfile","d":"io/burkard/cdk/services/nimblestudio/CfnLaunchProfile$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/CfnLaunchProfile$.html","n":"apply","t":"def apply(internalResourceId: String, streamConfiguration: StreamConfigurationProperty, ec2SubnetIds: List[String], name: String, studioComponentIds: List[String], launchProfileProtocolVersions: List[String], studioId: String, description: Option[String], tags: Option[Map[String, String]])(implicit stackCtx: Stack): CfnLaunchProfile","d":"io/burkard/cdk/services/nimblestudio/CfnLaunchProfile$","k":"def"},
{"l":"io/burkard/cdk/services/nimblestudio/CfnLaunchProfileProps$.html","n":"CfnLaunchProfileProps","t":"object CfnLaunchProfileProps","d":"io/burkard/cdk/services/nimblestudio/CfnLaunchProfileProps$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/CfnLaunchProfileProps$.html","n":"apply","t":"def apply(streamConfiguration: StreamConfigurationProperty, ec2SubnetIds: List[String], name: String, studioComponentIds: List[String], launchProfileProtocolVersions: List[String], studioId: String, description: Option[String], tags: Option[Map[String, String]]): CfnLaunchProfileProps","d":"io/burkard/cdk/services/nimblestudio/CfnLaunchProfileProps$","k":"def"},
{"l":"io/burkard/cdk/services/nimblestudio/CfnStreamingImage$.html","n":"CfnStreamingImage","t":"object CfnStreamingImage","d":"io/burkard/cdk/services/nimblestudio/CfnStreamingImage$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/CfnStreamingImage$.html","n":"apply","t":"def apply(internalResourceId: String, name: String, ec2ImageId: String, studioId: String, description: Option[String], tags: Option[Map[String, String]])(implicit stackCtx: Stack): CfnStreamingImage","d":"io/burkard/cdk/services/nimblestudio/CfnStreamingImage$","k":"def"},
{"l":"io/burkard/cdk/services/nimblestudio/CfnStreamingImageProps$.html","n":"CfnStreamingImageProps","t":"object CfnStreamingImageProps","d":"io/burkard/cdk/services/nimblestudio/CfnStreamingImageProps$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/CfnStreamingImageProps$.html","n":"apply","t":"def apply(name: String, ec2ImageId: String, studioId: String, description: Option[String], tags: Option[Map[String, String]]): CfnStreamingImageProps","d":"io/burkard/cdk/services/nimblestudio/CfnStreamingImageProps$","k":"def"},
{"l":"io/burkard/cdk/services/nimblestudio/CfnStudio$.html","n":"CfnStudio","t":"object CfnStudio","d":"io/burkard/cdk/services/nimblestudio/CfnStudio$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/CfnStudio$.html","n":"apply","t":"def apply(internalResourceId: String, displayName: String, studioName: String, adminRoleArn: String, userRoleArn: String, studioEncryptionConfiguration: Option[StudioEncryptionConfigurationProperty], tags: Option[Map[String, String]])(implicit stackCtx: Stack): CfnStudio","d":"io/burkard/cdk/services/nimblestudio/CfnStudio$","k":"def"},
{"l":"io/burkard/cdk/services/nimblestudio/CfnStudioComponent$.html","n":"CfnStudioComponent","t":"object CfnStudioComponent","d":"io/burkard/cdk/services/nimblestudio/CfnStudioComponent$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/CfnStudioComponent$.html","n":"apply","t":"def apply(internalResourceId: String, name: String, studioId: String, `type`: String, subtype: Option[String], initializationScripts: Option[List[_]], description: Option[String], tags: Option[Map[String, String]], ec2SecurityGroupIds: Option[List[String]], configuration: Option[StudioComponentConfigurationProperty], scriptParameters: Option[List[_]])(implicit stackCtx: Stack): CfnStudioComponent","d":"io/burkard/cdk/services/nimblestudio/CfnStudioComponent$","k":"def"},
{"l":"io/burkard/cdk/services/nimblestudio/CfnStudioComponentProps$.html","n":"CfnStudioComponentProps","t":"object CfnStudioComponentProps","d":"io/burkard/cdk/services/nimblestudio/CfnStudioComponentProps$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/CfnStudioComponentProps$.html","n":"apply","t":"def apply(name: String, studioId: String, `type`: String, subtype: Option[String], initializationScripts: Option[List[_]], description: Option[String], tags: Option[Map[String, String]], ec2SecurityGroupIds: Option[List[String]], configuration: Option[StudioComponentConfigurationProperty], scriptParameters: Option[List[_]]): CfnStudioComponentProps","d":"io/burkard/cdk/services/nimblestudio/CfnStudioComponentProps$","k":"def"},
{"l":"io/burkard/cdk/services/nimblestudio/CfnStudioProps$.html","n":"CfnStudioProps","t":"object CfnStudioProps","d":"io/burkard/cdk/services/nimblestudio/CfnStudioProps$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/CfnStudioProps$.html","n":"apply","t":"def apply(displayName: String, studioName: String, adminRoleArn: String, userRoleArn: String, studioEncryptionConfiguration: Option[StudioEncryptionConfigurationProperty], tags: Option[Map[String, String]]): CfnStudioProps","d":"io/burkard/cdk/services/nimblestudio/CfnStudioProps$","k":"def"},
{"l":"io/burkard/cdk/services/nimblestudio/ComputeFarmConfigurationProperty$.html","n":"ComputeFarmConfigurationProperty","t":"object ComputeFarmConfigurationProperty","d":"io/burkard/cdk/services/nimblestudio/ComputeFarmConfigurationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/ComputeFarmConfigurationProperty$.html","n":"apply","t":"def apply(endpoint: Option[String], activeDirectoryUser: Option[String]): ComputeFarmConfigurationProperty","d":"io/burkard/cdk/services/nimblestudio/ComputeFarmConfigurationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/nimblestudio/LicenseServiceConfigurationProperty$.html","n":"LicenseServiceConfigurationProperty","t":"object LicenseServiceConfigurationProperty","d":"io/burkard/cdk/services/nimblestudio/LicenseServiceConfigurationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/LicenseServiceConfigurationProperty$.html","n":"apply","t":"def apply(endpoint: Option[String]): LicenseServiceConfigurationProperty","d":"io/burkard/cdk/services/nimblestudio/LicenseServiceConfigurationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/nimblestudio/ScriptParameterKeyValueProperty$.html","n":"ScriptParameterKeyValueProperty","t":"object ScriptParameterKeyValueProperty","d":"io/burkard/cdk/services/nimblestudio/ScriptParameterKeyValueProperty$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/ScriptParameterKeyValueProperty$.html","n":"apply","t":"def apply(value: Option[String], key: Option[String]): ScriptParameterKeyValueProperty","d":"io/burkard/cdk/services/nimblestudio/ScriptParameterKeyValueProperty$","k":"def"},
{"l":"io/burkard/cdk/services/nimblestudio/SharedFileSystemConfigurationProperty$.html","n":"SharedFileSystemConfigurationProperty","t":"object SharedFileSystemConfigurationProperty","d":"io/burkard/cdk/services/nimblestudio/SharedFileSystemConfigurationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/SharedFileSystemConfigurationProperty$.html","n":"apply","t":"def apply(windowsMountDrive: Option[String], endpoint: Option[String], linuxMountPoint: Option[String], shareName: Option[String], fileSystemId: Option[String]): SharedFileSystemConfigurationProperty","d":"io/burkard/cdk/services/nimblestudio/SharedFileSystemConfigurationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/nimblestudio/StreamConfigurationProperty$.html","n":"StreamConfigurationProperty","t":"object StreamConfigurationProperty","d":"io/burkard/cdk/services/nimblestudio/StreamConfigurationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/StreamConfigurationProperty$.html","n":"apply","t":"def apply(streamingImageIds: List[String], clipboardMode: String, ec2InstanceTypes: List[String], maxSessionLengthInMinutes: Option[Number]): StreamConfigurationProperty","d":"io/burkard/cdk/services/nimblestudio/StreamConfigurationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/nimblestudio/StudioComponentConfigurationProperty$.html","n":"StudioComponentConfigurationProperty","t":"object StudioComponentConfigurationProperty","d":"io/burkard/cdk/services/nimblestudio/StudioComponentConfigurationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/StudioComponentConfigurationProperty$.html","n":"apply","t":"def apply(activeDirectoryConfiguration: Option[ActiveDirectoryConfigurationProperty], computeFarmConfiguration: Option[ComputeFarmConfigurationProperty], licenseServiceConfiguration: Option[LicenseServiceConfigurationProperty], sharedFileSystemConfiguration: Option[SharedFileSystemConfigurationProperty]): StudioComponentConfigurationProperty","d":"io/burkard/cdk/services/nimblestudio/StudioComponentConfigurationProperty$","k":"def"},
{"l":"io/burkard/cdk/services/nimblestudio/StudioComponentInitializationScriptProperty$.html","n":"StudioComponentInitializationScriptProperty","t":"object StudioComponentInitializationScriptProperty","d":"io/burkard/cdk/services/nimblestudio/StudioComponentInitializationScriptProperty$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/StudioComponentInitializationScriptProperty$.html","n":"apply","t":"def apply(platform: Option[String], script: Option[String], launchProfileProtocolVersion: Option[String], runContext: Option[String]): StudioComponentInitializationScriptProperty","d":"io/burkard/cdk/services/nimblestudio/StudioComponentInitializationScriptProperty$","k":"def"},
{"l":"io/burkard/cdk/services/nimblestudio/StudioEncryptionConfigurationProperty$.html","n":"StudioEncryptionConfigurationProperty","t":"object StudioEncryptionConfigurationProperty","d":"io/burkard/cdk/services/nimblestudio/StudioEncryptionConfigurationProperty$","k":"object"},
{"l":"io/burkard/cdk/services/nimblestudio/StudioEncryptionConfigurationProperty$.html","n":"apply","t":"def apply(keyType: String, keyArn: Option[String]): StudioEncryptionConfigurationProperty","d":"io/burkard/cdk/services/nimblestudio/StudioEncryptionConfigurationProperty$","k":"def"},
{"l":"docs/index.html","n":"nimblestudio","t":"nimblestudio","d":"","k":"static"}];
